@@ -46,6 +46,17 @@ def test_product_projections_get_by_key(client):
     assert product.key == product_create.key
 
 
+def test_product_projections_query_parameters_are_passed(client, commercetools_api):
+    client.products.query(
+        expand="productType", price_country="GB", price_currency="GBP"
+    )
+
+    last_request = commercetools_api.requests_mock.request_history[-1]
+
+    for field in ["expand", "priceCurrency", "priceCountry"]:
+        assert field in last_request.qs
+
+
 def test_product_projections_get_by_key_not_found(client):
     with pytest.raises(HTTPError):
         client.products.get_by_key("invalid")
